@@ -6,13 +6,12 @@ from django.contrib import admin
 from .models import PageTags, TitleTags
 
 
-
 class PageTagsAdmin(PageExtensionAdmin):
 
     class Media:
         css = {
             'all': ('%sdjangocms_page_tags/css/%s' % (
-                settings.STATIC_URL, "djangocms_page_tags.css"),)
+                settings.STATIC_URL, "djangocms_page_tags_admin.css"),)
         }
 admin.site.register(PageTags, PageTagsAdmin)
 
@@ -22,6 +21,6 @@ class TitleTagsAdmin(TitleExtensionAdmin):
     class Media:
         css = {
             'all': ('%sdjangocms_page_tags/css/%s' % (
-                settings.STATIC_URL, "djangocms_page_tags.css"),)
+                settings.STATIC_URL, "djangocms_page_tags_admin.css"),)
         }
-admin.site.register(TitleTags, TitleTagsAdmin)
\ No newline at end of file
+admin.site.register(TitleTags, TitleTagsAdmin)
